@@ -16,9 +16,9 @@ This is usually done as part of the release process.
 =cut
 
 our %GithubUsers = (
-	'Octo'      => '@octo',
-	'Mfournier' => '@mfournier',
-	'Tokkee'    => '@tokkee',
+	'Mfournier'    => '@mfournier',
+	'Octo'         => '@octo',
+	'Tokkee'       => '@tokkee',
 );
 
 sub format_link
@@ -26,12 +26,14 @@ sub format_link
 	my $page = shift;
 	my $text = @_ ? shift : $page;
 
-	if ($page =~ m/^User:([A-Z][a-z]*)/) {
+	if ($page =~ m/^User:([A-Z][a-z]*)$/) {
 		if (exists ($GithubUsers{$1})) {
 			return $GithubUsers{$1};
 		}
 	}
 
+	$page =~ s# #_#g;
+
 	return "[$text](https://collectd.org/wiki/index.php/$page)";
 }
 
@@ -46,12 +48,15 @@ while (<>)
 		next;
 	}
 
-	$line =~ s#\{\{Plugin\|([^}]+)\}\}#[$1 plugin](https://collectd.org/wiki/index.php/Plugin:$1)#g;
+	$line =~ s#(?<!\[)\[([^\s\]]+)\s+([^\]]+)\](?!\])#[$2]($1)#g;
+	$line =~ s#\{\{Plugin\|([^}]+)\}\}#format_link("Plugin:$1", "$1 plugin")#ge;
 	$line =~ s@\{\{Issue\|([^}]+)\}\}@#$1@g;
-	$line =~ s#\[\[([^|]+)\|([^\]]+)\]\]#format_link($1, $2)#ge;
-	$line =~ s#\[\[([^|]+)\]\]#format_link($1)#ge;
+	$line =~ s#\[\[([^|\]]+)\|([^\]]+)\]\]#format_link($1, $2)#ge;
+	$line =~ s#\[\[([^|\]]+)\]\]#format_link($1)#ge;
 
 	$line =~ s#('')?Ruben Kerkhof('')?#\@rubenk#g;
+	$line =~ s#('')?Pavel Rochnyak('')?#\@rpv-tomsk#g;
+	$line =~ s#('')?Maryam Tahhan('')?#\@maryamtahhan#g;
 
 	$line =~ s#'''(.*?)'''#**$1**#g;
 	$line =~ s#''(.*?)''#*$1*#g;
