@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -70,7 +70,7 @@
 #include "aux_types.h"
 
 static char *unquote (const char *orig);
-static int yyerror (const char *s);
+static void yyerror(const char *s);
 
 /* Lexer variables */
 extern int yylineno;
@@ -139,7 +139,7 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
 #line 47 "src/liboconfig/parser.y" /* yacc.c:355  */
@@ -154,6 +154,8 @@ union YYSTYPE
 
 #line 156 "src/liboconfig/parser.c" /* yacc.c:355  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -167,7 +169,7 @@ int yyparse (void);
 
 /* Copy the second part of user declarations.  */
 
-#line 171 "src/liboconfig/parser.c" /* yacc.c:358  */
+#line 173 "src/liboconfig/parser.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -465,9 +467,9 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    82,    82,    83,    87,    88,    89,    90,    94,   101,
-     110,   114,   124,   130,   140,   147,   160,   176,   177,   178,
-     182,   192,   209,   216
+       0,    82,    82,    83,    87,    88,    89,    90,    94,   107,
+     120,   124,   134,   140,   150,   157,   170,   186,   187,   188,
+     192,   208,   229,   240
 };
 #endif
 
@@ -1262,177 +1264,197 @@ yyreduce:
         case 2:
 #line 82 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.string) = unquote ((yyvsp[0].string));}
-#line 1266 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1268 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 3:
 #line 83 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.string) = strdup ((yyvsp[0].string));}
-#line 1272 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1274 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 4:
 #line 87 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.cv).value.number = (yyvsp[0].number); (yyval.cv).type = OCONFIG_TYPE_NUMBER;}
-#line 1278 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1280 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 5:
 #line 88 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.cv).value.boolean = 1; (yyval.cv).type = OCONFIG_TYPE_BOOLEAN;}
-#line 1284 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1286 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 6:
 #line 89 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.cv).value.boolean = 0; (yyval.cv).type = OCONFIG_TYPE_BOOLEAN;}
-#line 1290 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1292 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 7:
 #line 90 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.cv).value.string = (yyvsp[0].string); (yyval.cv).type = OCONFIG_TYPE_STRING;}
-#line 1296 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1298 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 8:
 #line 95 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
 	 (yyval.al) = (yyvsp[-1].al);
+	 oconfig_value_t *tmp = realloc((yyval.al).argument,
+	                                ((yyval.al).argument_num+1) * sizeof(*(yyval.al).argument));
+	 if (tmp == NULL) {
+	   yyerror("realloc failed");
+	   YYERROR;
+	 }
+	 (yyval.al).argument = tmp;
+	 (yyval.al).argument[(yyval.al).argument_num] = (yyvsp[0].cv);
 	 (yyval.al).argument_num++;
-	 (yyval.al).argument = realloc ((yyval.al).argument, (yyval.al).argument_num * sizeof (oconfig_value_t));
-	 (yyval.al).argument[(yyval.al).argument_num-1] = (yyvsp[0].cv);
 	}
-#line 1307 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1315 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 102 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 108 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 (yyval.al).argument = malloc (sizeof (oconfig_value_t));
+	 (yyval.al).argument = calloc(1, sizeof(*(yyval.al).argument));
+	 if ((yyval.al).argument == NULL) {
+	   yyerror("calloc failed");
+	   YYERROR;
+	 }
 	 (yyval.al).argument[0] = (yyvsp[0].cv);
 	 (yyval.al).argument_num = 1;
 	}
-#line 1317 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1329 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 110 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 120 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {(yyval.string) = strdup ((yyvsp[0].string));}
-#line 1323 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1335 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 115 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 125 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 memset (&(yyval.ci), '\0', sizeof ((yyval.ci)));
+	 memset(&(yyval.ci), 0, sizeof((yyval.ci)));
 	 (yyval.ci).key = (yyvsp[-2].string);
 	 (yyval.ci).values = (yyvsp[-1].al).argument;
 	 (yyval.ci).values_num = (yyvsp[-1].al).argument_num;
 	}
-#line 1334 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1346 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 125 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 135 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 memset (&(yyval.ci), '\0', sizeof ((yyval.ci)));
+	 memset(&(yyval.ci), 0, sizeof((yyval.ci)));
 	 (yyval.ci).key = (yyvsp[-2].string);
 	}
-#line 1343 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1355 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 131 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 141 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 memset (&(yyval.ci), '\0', sizeof ((yyval.ci)));
+	 memset(&(yyval.ci), 0, sizeof((yyval.ci)));
 	 (yyval.ci).key = (yyvsp[-3].string);
 	 (yyval.ci).values = (yyvsp[-2].al).argument;
 	 (yyval.ci).values_num = (yyvsp[-2].al).argument_num;
 	}
-#line 1354 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1366 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 141 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 151 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
 	 (yyval.string) = (yyvsp[-2].string);
 	}
-#line 1362 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1374 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 148 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 158 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 if (strcmp ((yyvsp[-2].ci).key, (yyvsp[0].string)) != 0)
+	 if (strcmp((yyvsp[-2].ci).key, (yyvsp[0].string)) != 0)
 	 {
-		printf ("block_begin = %s; block_end = %s;\n", (yyvsp[-2].ci).key, (yyvsp[0].string));
-	 	yyerror ("Block not closed..\n");
-		exit (1);
+		printf("block_begin = %s; block_end = %s;\n", (yyvsp[-2].ci).key, (yyvsp[0].string));
+		yyerror("block not closed");
+		YYERROR;
 	 }
 	 free ((yyvsp[0].string)); (yyvsp[0].string) = NULL;
 	 (yyval.ci) = (yyvsp[-2].ci);
 	 (yyval.ci).children = (yyvsp[-1].sl).statement;
 	 (yyval.ci).children_num = (yyvsp[-1].sl).statement_num;
 	}
-#line 1379 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1391 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 161 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 171 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 if (strcmp ((yyvsp[-1].ci).key, (yyvsp[0].string)) != 0)
+	 if (strcmp((yyvsp[-1].ci).key, (yyvsp[0].string)) != 0)
 	 {
-		printf ("block_begin = %s; block_end = %s;\n", (yyvsp[-1].ci).key, (yyvsp[0].string));
-		yyerror ("Block not closed..\n");
-		exit (1);
+		printf("block_begin = %s; block_end = %s;\n", (yyvsp[-1].ci).key, (yyvsp[0].string));
+		yyerror("block not closed");
+		YYERROR;
 	 }
 	 free ((yyvsp[0].string)); (yyvsp[0].string) = NULL;
 	 (yyval.ci) = (yyvsp[-1].ci);
 	 (yyval.ci).children = NULL;
 	 (yyval.ci).children_num = 0;
 	}
-#line 1396 "src/liboconfig/parser.c" /* yacc.c:1646  */
-    break;
-
-  case 17:
-#line 176 "src/liboconfig/parser.y" /* yacc.c:1646  */
-    {(yyval.ci) = (yyvsp[0].ci);}
-#line 1402 "src/liboconfig/parser.c" /* yacc.c:1646  */
-    break;
-
-  case 18:
-#line 177 "src/liboconfig/parser.y" /* yacc.c:1646  */
-    {(yyval.ci) = (yyvsp[0].ci);}
 #line 1408 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
-  case 19:
-#line 178 "src/liboconfig/parser.y" /* yacc.c:1646  */
-    {(yyval.ci).values_num = 0;}
+  case 17:
+#line 186 "src/liboconfig/parser.y" /* yacc.c:1646  */
+    {(yyval.ci) = (yyvsp[0].ci);}
 #line 1414 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
+  case 18:
+#line 187 "src/liboconfig/parser.y" /* yacc.c:1646  */
+    {(yyval.ci) = (yyvsp[0].ci);}
+#line 1420 "src/liboconfig/parser.c" /* yacc.c:1646  */
+    break;
+
+  case 19:
+#line 188 "src/liboconfig/parser.y" /* yacc.c:1646  */
+    {(yyval.ci).values_num = 0;}
+#line 1426 "src/liboconfig/parser.c" /* yacc.c:1646  */
+    break;
+
   case 20:
-#line 183 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 193 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
 	 (yyval.sl) = (yyvsp[-1].sl);
 	 if (((yyvsp[0].ci).values_num > 0) || ((yyvsp[0].ci).children_num > 0))
 	 {
+		 oconfig_item_t *tmp = realloc((yyval.sl).statement,
+		                               ((yyval.sl).statement_num+1) * sizeof(*tmp));
+		 if (tmp == NULL) {
+		   yyerror("realloc failed");
+		   YYERROR;
+		 }
+		 (yyval.sl).statement = tmp;
+		 (yyval.sl).statement[(yyval.sl).statement_num] = (yyvsp[0].ci);
 		 (yyval.sl).statement_num++;
-		 (yyval.sl).statement = realloc ((yyval.sl).statement, (yyval.sl).statement_num * sizeof (oconfig_item_t));
-		 (yyval.sl).statement[(yyval.sl).statement_num-1] = (yyvsp[0].ci);
 	 }
 	}
-#line 1428 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1446 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 193 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 209 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
 	 if (((yyvsp[0].ci).values_num > 0) || ((yyvsp[0].ci).children_num > 0))
 	 {
-		 (yyval.sl).statement = malloc (sizeof (oconfig_item_t));
+		 (yyval.sl).statement = calloc(1, sizeof(*(yyval.sl).statement));
+		 if ((yyval.sl).statement == NULL) {
+		   yyerror("calloc failed");
+		   YYERROR;
+		 }
 		 (yyval.sl).statement[0] = (yyvsp[0].ci);
 		 (yyval.sl).statement_num = 1;
 	 }
@@ -1442,31 +1464,37 @@ yyreduce:
 		(yyval.sl).statement_num = 0;
 	 }
 	}
-#line 1446 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1468 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 210 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 230 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 ci_root = calloc (1, sizeof (*ci_root));
+	 ci_root = calloc(1, sizeof(*ci_root));
+	 if (ci_root == NULL) {
+	   yyerror("calloc failed");
+	   YYERROR;
+	 }
 	 ci_root->children = (yyvsp[0].sl).statement;
 	 ci_root->children_num = (yyvsp[0].sl).statement_num;
 	}
-#line 1456 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1482 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 216 "src/liboconfig/parser.y" /* yacc.c:1646  */
+#line 240 "src/liboconfig/parser.y" /* yacc.c:1646  */
     {
-	 ci_root = calloc (1, sizeof (*ci_root));
-	 ci_root->children = NULL;
-	 ci_root->children_num = 0;
+	 ci_root = calloc(1, sizeof(*ci_root));
+	 if (ci_root == NULL) {
+	   yyerror("calloc failed");
+	   YYERROR;
+	 }
 	}
-#line 1466 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1494 "src/liboconfig/parser.c" /* yacc.c:1646  */
     break;
 
 
-#line 1470 "src/liboconfig/parser.c" /* yacc.c:1646  */
+#line 1498 "src/liboconfig/parser.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1694,20 +1722,21 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 223 "src/liboconfig/parser.y" /* yacc.c:1906  */
+#line 249 "src/liboconfig/parser.y" /* yacc.c:1906  */
 
-static int yyerror (const char *s)
+static void yyerror(const char *s)
 {
 	const char *text;
 
-	if (*yytext == '\n')
+	if (yytext == NULL)
+		text = "<empty>";
+	else if (*yytext == '\n')
 		text = "<newline>";
 	else
 		text = yytext;
 
-	fprintf (stderr, "Parse error in file `%s', line %i near `%s': %s\n",
+	fprintf(stderr, "Parse error in file `%s', line %i near `%s': %s\n",
 		c_file, yylineno, text, s);
-	return (-1);
 } /* int yyerror */
 
 static char *unquote (const char *orig)
@@ -1725,7 +1754,7 @@ static char *unquote (const char *orig)
 
 	len -= 2;
 	memmove (ret, ret + 1, len);
-	ret[len] = '\0';
+	ret[len] = 0;
 
 	for (int i = 0; i < len; i++)
 	{
