@@ -46,17 +46,17 @@ static int md_config(const char *key, const char *value) {
   if (ignorelist == NULL)
     ignorelist = ignorelist_create(/* invert = */ 1);
   if (ignorelist == NULL)
-    return (1);
+    return 1;
 
   if (strcasecmp(key, "Device") == 0) {
     ignorelist_add(ignorelist, value);
   } else if (strcasecmp(key, "IgnoreSelected") == 0) {
     ignorelist_set_invert(ignorelist, IS_TRUE(value) ? 0 : 1);
   } else {
-    return (-1);
+    return -1;
   }
 
-  return (0);
+  return 0;
 }
 
 static void md_submit(const int minor, const char *type_instance,
@@ -66,7 +66,7 @@ static void md_submit(const int minor, const char *type_instance,
   vl.values = &(value_t){.gauge = value};
   vl.values_len = 1;
   sstrncpy(vl.plugin, "md", sizeof(vl.plugin));
-  ssnprintf(vl.plugin_instance, sizeof(vl.plugin_instance), "%i", minor);
+  snprintf(vl.plugin_instance, sizeof(vl.plugin_instance), "%i", minor);
   sstrncpy(vl.type, "md_disks", sizeof(vl.type));
   sstrncpy(vl.type_instance, type_instance, sizeof(vl.type_instance));
 
@@ -149,7 +149,7 @@ static int md_read(void) {
     char errbuf[1024];
     WARNING("md: Unable to open %s: %s", PROC_DISKSTATS,
             sstrerror(errno, errbuf, sizeof(errbuf)));
-    return (-1);
+    return -1;
   }
 
   /* Iterate md devices */
@@ -180,14 +180,14 @@ static int md_read(void) {
      * major/minor, but that again can be tricky if the filesystem
      * with the device file is mounted using the "nodev" option.
      */
-    ssnprintf(path, sizeof(path), "%s/%s", DEV_DIR, name);
+    snprintf(path, sizeof(path), "%s/%s", DEV_DIR, name);
 
     md_process(minor, path);
   }
 
   fclose(fh);
 
-  return (0);
+  return 0;
 } /* int md_read */
 
 void module_register(void) {
